=======
Authors
=======

Development Lead
----------------

django-virtual-models is maintained by [Vinta Software](https://www.vintasoftware.com/). Lead maintainers:

* Flávio Juvenal da Silva Junior <flavio at vinta.com.br>

Contributors
------------

None yet. Why not be the first?
